@@ -6,6 +6,7 @@ import os
 import glob
 import numpy as np
 import string
+import warnings
 
 from .. import utils
 from .. import dataset
@@ -73,7 +74,11 @@ def make_flatmap_image(braindata, height=1024, recache=False, nanmean=False, **k
     if data.dtype == np.uint8:
         img = np.zeros(mask.shape+(4,), dtype=np.uint8)
         img[mask] = pixmap * data.reshape(-1, 4)
-        return img.transpose(1,0,2)[::-1], extents
+        img = img.transpose(1,0,2)[::-1]
+        # Make img a c-contiguous array or pil will complain when saving it
+        if not img.flags["C_CONTIGUOUS"]:
+            img = img.copy(order="C")
+        return img, extents
     else:
         badmask = np.array(pixmap.sum(1) > 0).ravel()
         img = (np.nan*np.ones(mask.shape)).astype(data.dtype)
@@ -90,12 +95,18 @@ def make_flatmap_image(braindata, height=1024, recache=False, nanmean=False, **k
             # sum(weights * non-nan values) / sum(weights on non-nan values)
             nonnan_sum = pixmap.dot(np.nan_to_num(data.ravel()))
             weights_on_nonnan = pixmap.dot((~np.isnan(data.ravel())).astype(data.dtype))
-            nanmean_data = nonnan_sum / weights_on_nonnan
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore", RuntimeWarning)
+                nanmean_data = nonnan_sum / weights_on_nonnan
             mimg[badmask] = nanmean_data[badmask].astype(mimg.dtype)
 
         img[mask] = mimg
+        img = img.T[::-1]
+        # Make img a c-contiguous array or pil will complain when saving it
+        if not img.flags["C_CONTIGUOUS"]:
+            img = img.copy(order="C")
 
-        return img.T[::-1], extents
+        return img, extents
 
 def get_flatmask(subject, height=1024, recache=False):
     """
@@ -309,9 +320,15 @@ def _make_hatch_image(hatch_data, height, sampler='nearest', hatch_space=4, reca
         space between hatch lines (in pixels)
     recache : boolean
 
-
+    Returns
+    -------
+    hatchim : RGBA array
+        flatmap image with hatches over hatch_data
     """
-    dmap, _ = make_flatmap_image(hatch_data, height=height, sampler=sampler, recache=recache)
+    dmap, _ = make_flatmap_image(
+        hatch_data, height=height, sampler=sampler, recache=recache, nanmean=True
+    )
+    mask_nans = np.isnan(dmap)
     hx, hy = np.meshgrid(range(dmap.shape[1]), range(dmap.shape[0]))
 
     hatchpat = (hx+hy)%(2*hatch_space) < 2
@@ -321,7 +338,9 @@ def _make_hatch_image(hatch_data, height, sampler='nearest', hatch_space=4, reca
 
     hatchpat = np.logical_or(hatchpat, hatchpat[:,::-1]).astype(float)
     hatchim = np.dstack([1-hatchpat]*3 + [hatchpat])
-    hatchim[:, : ,3] *= np.clip(dmap, 0, 1).astype(float)
+    hatchim[:, :, 3] *= np.clip(dmap, 0, 1).astype(float)
+    # Set nans to alpha = 0. for transparency
+    hatchim[mask_nans, 3] = 0.
 
     return hatchim
 
